spacr.settings — spacr 0.5.0 documentation

# spacr.settings

## Module Contents

spacr.settings.set_default_plot_merge_settings()

spacr.settings.set_default_settings_preprocess_generate_masks(settings={})

spacr.settings.set_default_settings_preprocess_img_data_v1(settings)

spacr.settings.set_default_settings_preprocess_img_data(settings)

spacr.settings.set_default_umap_image_settings(settings={})

spacr.settings.get_measure_crop_settings(settings={})

spacr.settings.set_default_analyze_screen(settings)

spacr.settings.set_default_train_test_model(settings)

spacr.settings.set_generate_training_dataset_defaults(settings)

spacr.settings.deep_spacr_defaults(settings)

spacr.settings.get_train_test_model_settings(settings)

spacr.settings.get_analyze_recruitment_default_settings(settings)

spacr.settings.get_default_test_cellpose_model_settings(settings)

spacr.settings.get_default_apply_cellpose_model_settings(settings)

spacr.settings.default_settings_analyze_percent_positive(settings)

spacr.settings.get_analyze_reads_default_settings(settings)

spacr.settings.get_map_barcodes_default_settings(settings)

spacr.settings.get_train_cellpose_default_settings(settings)

spacr.settings.set_generate_dataset_defaults(settings)

spacr.settings.get_perform_regression_default_settings(settings)

spacr.settings.get_check_cellpose_models_default_settings(settings)

spacr.settings.get_identify_masks_finetune_default_settings(settings)

spacr.settings.q = None

spacr.settings.expected_types

spacr.settings.categories

spacr.settings.category_keys = ['Paths', 'General', 'Cellpose', 'Cell', 'Nucleus', 'Pathogen', 'Measurements', 'Object Image',...

spacr.settings.check_settings(vars_dict, expected_types, q=None)

spacr.settings.generate_fields(variables, scrollable_frame)

spacr.settings.descriptions

spacr.settings.set_annotate_default_settings(settings)

spacr.settings.set_default_generate_barecode_mapping(settings={})

spacr.settings.get_default_generate_activation_map_settings(settings)

spacr.settings.get_analyze_plaque_settings(settings)

spacr.settings.set_graph_importance_defaults(settings)

spacr.settings.set_interperate_vision_model_defaults(settings)

spacr.settings.set_analyze_endodyogeny_defaults(settings)

spacr.settings.set_analyze_class_proportion_defaults(settings)